macro_rules! impl_hex_display {
($fragment_type:ty) => { ... };
}👎Deprecated since 2.1.0:
this implementation has been generalized and no longer requires a macro
macro_rules! impl_hex_display {
($fragment_type:ty) => { ... };
}this implementation has been generalized and no longer requires a macro