macro_rules! impl_input_iter {
() => { ... };
}👎Deprecated since 3.1.0:
this implementation has been generalized and no longer requires a macro
macro_rules! impl_input_iter {
() => { ... };
}this implementation has been generalized and no longer requires a macro